%% Simulate the space shuttle model.
% -------------------------------------------------------------------------
%  See also DrawSCPlugIn and BuildShuttle., QLVLH, QPose, StopGUI, RK4, 
%  JD2000, El2RV
% -------------------------------------------------------------------------
%%
%-------------------------------------------------------------------------------
%   Copyright 1999 Princeton Satellite Systems, Inc. All rights reserved.
%-------------------------------------------------------------------------------

%% Constants
%----------
degToRad = pi/180;

%% Global for the time GUI
%------------------------
global simulationAction
simulationAction = ' ';

g = load('ShuttleModel');

%% Initialize the orbits
%----------------------
[r1,v1] = El2RV( [7000 61*degToRad 0 0 0 0]);
x1      = [r1;v1];
t       = 0;
jD      = JD2000;

%% Initialize the 3D window
%-------------------------
g(1).body(1).bHinge.q = QPose(QLVLH( x1(1:3), x1(4:6) ));
g(1).rECI             = r1;
g(1).qLVLH            = QLVLH( x1(1:3), x1(4:6) );
g(1).name             = 'Space Shuttle Orbiter';
tag3DWindow           = DrawSCPlugIn( 'initialize', g, [], [], 'Earth', jD );

dTSim                 = 1;

%% Generate the two orbits using numerical integration
%----------------------------------------------------
doorAngle = 0;
rMSAngle  = 0;
StopGUI( 'Space Shuttle' );

rMSAxis = [3 2 2 2 2];

while t<1200
  
  % Transformation matrices
  %------------------------
  g(1).body(1).bHinge.q = QPose(QLVLH( x1(1:3), x1(4:6) ));
  g(1).rECI             = x1(1:3);
  g(1).qLVLH            = QLVLH( x1(1:3), x1(4:6) );
  if( doorAngle > -139 )
    doorAngle = doorAngle - 1;
  elseif( rMSAngle < 45 )
    rMSAngle = rMSAngle + 1;
  end
  g(1).body(2).bHinge = struct( 'angle',  doorAngle*pi/180, 'axis', 1 );
  g(1).body(3).bHinge = struct( 'angle', -doorAngle*pi/180, 'axis', 1 );
  for j = 1:5
    g(1).body(j+3).bHinge = struct( 'angle',  -rMSAngle*pi/180, 'axis', rMSAxis(j) );
  end
  
  DrawSCPlugIn( 'update spacecraft', tag3DWindow, g, jD );
  
  % Propagate the orbits
  %---------------------
  x1 = RK4( 'FOrbCart', x1, dTSim, t, [0;0;0] );
  
  % Update the time
  %----------------
  t  =  t + dTSim;
  jD = jD + dTSim/86400;
  
  % Time control
  %-------------
  switch simulationAction
    case 'pause'
      pause
      simulationAction = ' ';
    case 'stop'
      return;
    case 'plot'
      break;
  end
end


%--------------------------------------
% PSS internal file version information
%--------------------------------------
% $Date: 2010-09-17 12:32:26 -0500 (Fri, 17 Sep 2010) $
% $Revision: 22170 $
